@@ -317,7 +317,7 @@ sub parse_maps {
 
 	    close IN;
 
-	    print "Loaded $n type definitions from $file\n";
+	    #print "Loaded $n type definitions from $file\n";
 	}
 
 	# create output
@@ -359,9 +359,9 @@ sub parse_maps {
 	close OUT;
 
 	# mini report to stdout
-	foreach (sort keys %seen) {
-		printf "  %3d %s\n", $seen{$_}, $_;
-	}
+	# foreach (sort keys %seen) {
+	# 	printf "  %3d %s\n", $seen{$_}, $_;
+	# }
 
 	# fin.
 }
@@ -518,7 +518,7 @@ sub gen_boxed_stuff {
   /* GBoxed $classname */
   typedef $classname $classname\_ornull;
 # define Sv$classname(sv)	(gperl_get_boxed_check ((sv), $typemacro))
-# define Sv$classname\_ornull(sv)	(((sv) && SvOK (sv)) ? Sv$classname (sv) : NULL)
+# define Sv$classname\_ornull(sv)	(gperl_sv_defined (sv) ? Sv$classname (sv) : NULL)
   typedef $classname $classname\_own;
   typedef $classname $classname\_copy;
   typedef $classname $classname\_own_ornull;
@@ -553,7 +553,7 @@ sub gen_object_stuff {
 # define Sv$classname(sv)	(($classname*)gperl_get_object_check (sv, $typemacro))
 # define newSV$classname(val)	($get_wrapper)
   typedef $classname $classname\_ornull;
-# define Sv$classname\_ornull(sv)	(((sv) && SvOK (sv)) ? Sv$classname(sv) : NULL)
+# define Sv$classname\_ornull(sv)	(gperl_sv_defined (sv) ? Sv$classname(sv) : NULL)
 # define newSV$classname\_ornull(val)	(((val) == NULL) ? &PL_sv_undef : $get_wrapper)
 ";
 
