@@ -16,7 +16,7 @@
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.49 2007/09/15 14:10:12 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.51 2007/12/16 16:32:13 kaffeetisch Exp $
  */
 
 #ifndef _GPERL_H_
@@ -76,6 +76,8 @@ void gperl_argv_free (GPerlArgv *pargv);
 
 char * gperl_format_variable_for_output (SV * sv);
 
+gboolean gperl_sv_defined (SV *sv);
+
 /* internal trickery */
 gpointer gperl_type_class (GType type);
 /*
@@ -249,7 +251,7 @@ typedef GPerlFilename GPerlFilename_ornull;
 #define newSVGObject(obj)	(gperl_new_object ((obj), FALSE))
 #define newSVGObject_noinc(obj)	(gperl_new_object ((obj), TRUE))
 #define SvGObject(sv)		(gperl_get_object (sv))
-#define SvGObject_ornull(sv)	((sv && SvOK (sv)) ? SvGObject (sv) : NULL)
+#define SvGObject_ornull(sv)	(gperl_sv_defined (sv) ? SvGObject (sv) : NULL)
 
 
 /*
